pub struct ChargerSetChargingEnabledRequest {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for ChargerSetChargingEnabledRequest
impl Clone for ChargerSetChargingEnabledRequest
Sourcefn clone(&self) -> ChargerSetChargingEnabledRequest
fn clone(&self) -> ChargerSetChargingEnabledRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ChargerSetChargingEnabledRequest
Sourceimpl<D: ResourceDialect> Decode<ChargerSetChargingEnabledRequest, D> for ChargerSetChargingEnabledRequest
impl<D: ResourceDialect> Decode<ChargerSetChargingEnabledRequest, D> for ChargerSetChargingEnabledRequest
Sourceimpl<D: ResourceDialect> Encode<ChargerSetChargingEnabledRequest, D> for &ChargerSetChargingEnabledRequest
impl<D: ResourceDialect> Encode<ChargerSetChargingEnabledRequest, D> for &ChargerSetChargingEnabledRequest
Sourceimpl<D: ResourceDialect, T0: Encode<bool, D>> Encode<ChargerSetChargingEnabledRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<bool, D>> Encode<ChargerSetChargingEnabledRequest, D> for (T0,)
impl Eq for ChargerSetChargingEnabledRequest
Sourceimpl Ord for ChargerSetChargingEnabledRequest
impl Ord for ChargerSetChargingEnabledRequest
Sourcefn cmp(&self, other: &ChargerSetChargingEnabledRequest) -> Ordering
fn cmp(&self, other: &ChargerSetChargingEnabledRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for ChargerSetChargingEnabledRequest
impl PartialOrd for ChargerSetChargingEnabledRequest
impl Persistable for ChargerSetChargingEnabledRequest
impl StructuralPartialEq for ChargerSetChargingEnabledRequest
Sourceimpl TypeMarker for ChargerSetChargingEnabledRequest
impl TypeMarker for ChargerSetChargingEnabledRequest
Sourcetype Owned = ChargerSetChargingEnabledRequest
type Owned = ChargerSetChargingEnabledRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ChargerSetChargingEnabledRequest
impl ValueTypeMarker for ChargerSetChargingEnabledRequest
Sourcetype Borrowed<'a> = &'a ChargerSetChargingEnabledRequest
type Borrowed<'a> = &'a ChargerSetChargingEnabledRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for ChargerSetChargingEnabledRequest
impl RefUnwindSafe for ChargerSetChargingEnabledRequest
impl Send for ChargerSetChargingEnabledRequest
impl Sync for ChargerSetChargingEnabledRequest
impl Unpin for ChargerSetChargingEnabledRequest
impl UnsafeUnpin for ChargerSetChargingEnabledRequest
impl UnwindSafe for ChargerSetChargingEnabledRequest